@@ -1,14 +1,15 @@
 """OLAP Cubes"""
 
-__version__ = "1.0.1"
+__version__ = "1.1"
 
 from .common import *
 from .browser import *
+from .cells import *
 from .model import *
 from .metadata import *
 from .workspace import *
 from .errors import *
-from .formatter import *
+from .formatters import *
 from .computation import *
 from .mapper import *
 from .providers import *
