@@ -2,7 +2,7 @@
 
 import os
 from .base import create_server
-from .common import str_to_bool
+from .utils import str_to_bool
 
 # Set the configuration file
 try:
